==> kzFauxTexte-1_0_0.zip: kzFauxTexte/kzFauxTexte.php <==
<?php
if(!defined('PLX_ROOT')) { exit; }

class kzFauxTexte extends plxPlugin {

	const HOOKS = array(
		'AdminTopEndHead',
	);

	const DEBUG = false;

	const MIN_ARTS = 2;
	const MAX_ARTS = 9990;
	const MIN_PARAS = 2;
	const MAX_PARAS = 9;
	const MIN_SIZE = 40;
	const MAX_SIZE = 500;
	const STEP_SIZE = 20;
	const TAGS_COUNT = 30;

	const CONTENT_START = '<p>' . PHP_EOL;
	const CONTENT_END = PHP_EOL . '<p>';
	const CONTENT_SEP = PHP_EOL . '</p><p>' . PHP_EOL;

	// Pour la recherche de tags: mots à exclure
	const PATTERN = '@(?:ai(?:en)?t|ent|aujourd|encore|quelques?|(?:ce)?pendant|de(?:puis|vant)|contre|jamais|contre|maintenant|toutes|monsieur|madame|beaucoup|lorsque?|ailleurs|chaque)$@';
	public  $default_values = array(
		'ebook'			=> '',
		'paragraphs'	=> 6,
		'minsize'		=> 60,
		'maxsize'		=> 400,
		'articles'		=> 120,
		'author'		=> '',
		'categorie'		=> '',
		'medias'		=> '',
		'thumb'			=> 0,
		'begin'			=> '',
		'template'		=> 'article.php',
		'replace_all'	=> '0', // replace each old article with a new one.
	);

	public function __construct($lang) {
		parent::__construct($lang);

		if(!defined('PLX_ADMIN')) { return; }

		$this->setAdminProfil(PROFIL_ADMIN);
		$this->setAdminMenu($this->getLang('FAUX_TEXTE'), false, 'Plugin ' . __CLASS__);
		foreach(self::HOOKS as $hook) {
			$this->addHook($hook, $hook);
		}
		$this->default_values['begin'] = date('Y-m-d', time() - 47304000); // 365jours x 1.5
	}

	public function getEbooks() {
		$result = array();
		foreach(array_map(
			function($item) { return basename($item, '.epub'); },
			glob(PLX_PLUGINS . __CLASS__ . '/*.epub')) as $k
		) {
			$result[$k] = $k;
		}
		return  $result;
	}

	public function getAuthors() {
		$instance = plxAdmin::getInstance();
		$result = array('' => $this->getLang('ALL'));
		foreach($instance->aUsers as $id=>$infos) {
			$result[$id] = $infos['name'];
		}
		return $result;
	}

	public function getCategories() {
		$instance = plxAdmin::getInstance();
		$result = array(
			''		=> $this->getLang('ALL'),
			'000'	=> L_UNCLASSIFIED,
		);
		foreach($instance->aCats as $id=>$infos) {
			$result[$id] = $infos['name'];
		}
		return $result;
	}

	public function getMedias() {
		$instance = plxAdmin::getInstance();
		if(empty($instance->aConf['medias'])) {
			return array('NONE');
		}

		$root = rtrim(PLX_ROOT . $instance->aConf['medias'], '/');
		$start = strlen(PLX_ROOT);
		$motif = '/*';
		$folders =  array(
			'' => $this->getLang('NONE'),
			rtrim($instance->aConf['medias'], '/') => $this->getLang('ROOT'),
		);
		for($i=1; $i<5; $i++) {
			$buffer = array_map(
				function($item) use($start) { return substr($item, $start); },
				glob($root . str_repeat($motif, $i), GLOB_ONLYDIR));
			if(empty($buffer)) { break; }
			foreach($buffer as $k=>$v) {
				// $last = ($k < count($buffer) - 1) ? '├─ ' : '└─ ';
				// $folders[$v] = str_repeat('│  ', $i - 1) . $last . basename($v); // Not a space, but u+2007 (figure space)
				$folders[$v] = str_repeat('   ', $i) . basename($v); // Not a space, but u+2007 (figure space)
			}
		}
		ksort($folders);
		return $folders;
	}

	public function getTemplates() {
		$result = array();
		$instance = plxAdmin::getInstance();
		foreach(glob(PLX_ROOT . $instance->aConf['racine_themes'] . $instance->aConf['style'] . '/article*.php') as $filename) {
			$result[basename($filename)] = basename($filename, '.php');
		}
		return $result;
	}


	public function printStylesheet() {
?>
		<link rel="stylesheet" href="<?= PLX_PLUGINS . __CLASS__ ?>/css/admin.css" />
<?php
	}

	// Pseudo tirage gaussien
	private function __array_rand(array &$t) {
		$average = intval(count($t) / 2);
		return mt_rand(mt_rand(0, $average), mt_rand($average, count($t)-1));
	}

	private function parseEbook(string $filename) {
		$zip = new ZipArchive;
		if($zip->open($filename) === true) {
			$content = $zip->getFromName('META-INF/container.xml');
			$doc = simplexml_load_string($content);
			$rootfile = $doc->rootfiles[0]->rootfile['full-path'];

			$content = $zip->getFromName($rootfile);
			$doc = simplexml_load_string($content);

			$this->entries = array();
			$this->sizes = array();
			$words = array();
			$doc->registerXPathNamespace('a', 'http://www.idpf.org/2007/opf');
			foreach($doc->xpath('//a:manifest/a:item[@media-type="application/xhtml+xml"]') as $t) {
				$href = dirname($rootfile) . '/' . $t['href'];
				$content = $zip->getFromName($href);
				$dom = new DomDocument;
				$dom->loadHTML($content);
				# On recherche les balises <p>
				foreach($dom->getElementsByTagName('p') as $paragraph) {
					$value = trim(preg_replace('@[\r\n]+@', ' ', $paragraph->nodeValue));
					$size = strlen($value);
					if($size >= 40 and $size <= self::MAX_SIZE) { // Entre 72 et 400 octets par entrée
						$n = count($this->entries);
						$this->entries[] = $value;
						$k = intval(round($size / self::STEP_SIZE));
						if(empty($this->sizes[$k])) {
							$this->sizes[$k] = array($n);
						} else {
							$this->sizes[$k][] = $n;
						}
						if(preg_match_all('@(\w{6,})@mu', strtolower($value), $matches)) {
							foreach($matches[1] as $w) {
								// On exclut certains mots
								if(preg_match(self::PATTERN, $w) == 0) {
									if(array_key_exists($w, $words)) {
										$words[$w]++;
									} else {
										$words[$w] = 1;
									}
								}
							}

						}
					}
				}
			}
			$zip->close();
			foreach(array_keys($this->sizes) as $k) {
				shuffle($this->sizes[$k]);
			}
			ksort($this->sizes);
			arsort($words);
			$this->tags = array_slice(array_keys($words), 0, self::TAGS_COUNT);
			shuffle($this->tags);

			if(self::DEBUG) {
				$output = array();
				foreach($words as $k=>$v) {
					$output[] = $k . ' : ' . $v;
				}
				file_put_contents(preg_replace('@\.xml$@', '.srt', $this->plug['parameters.xml']), implode(PHP_EOL, $output));
			}
		}
	}

	public function createArticles() {
		// Tester si le livre existe toujours
		$this->parseEbook(PLX_PLUGINS . __CLASS__ . '/' . $this->getParam('ebook') . '.epub');
		if(empty($this->entries)) { return; }

		$instance = plxAdmin::getInstance();

		# La liste des articles n'est pas actualisée en temps réel ( plxAdmin::nextIdArticle() )
		$aKeys = array_keys($instance->plxGlob_arts->aFiles);
		$artIdNum = 1;

		if(!empty($this->getParam('replace_all'))) {
			// On supprime tous les articles existants
			foreach($aKeys as $idArt) {
				$instance->delArticle($idArt);
			}
		} elseif(!empty($aKeys)) {
			rsort($aKeys);
			$artIdNum = intval(ltrim($aKeys[0], '0')) + 1;
		}

		$jMax = $this->getParam('paragraphs') + 1; // Un paragraphe supplémentaire pour le chapo
		$min = $this->getParam('minsize') / self::STEP_SIZE;
		$max = $this->getParam('maxsize') / self::STEP_SIZE;
		if($max < $min) { $max = $min; }

		$folder = rtrim($this->getParam('medias'), '/');
		if(!empty($folder)) {
			$start = strlen(PLX_ROOT);
			$medias = array_map(
				function($item) use($start) {
					return substr($item, $start); // On vire PLX_ROOT
				},
				array_filter(
					glob(PLX_ROOT . $folder . '/*'),
					function($filename) { return (preg_match('@(\.tb)?\.(?:jpe?g|png|gif|svg)$@', basename($filename), $matches) and empty($matches[1])); }
				)
			);
			if(empty($this->getParam('thumb'))) {
				$medias[] = ''; // article sans vignette
			}
		} else {
			$medias = false;
		}

		list($year, $month, $day) = explode('-', $this->getParam('begin'));
		$periode_start = mktime(0, 0, 0, ltrim($month, '0'), ltrim($day, '0'), $year);
		$periode_end = time();

		$titlesList = array();

		$aCat = $this->getParam('categorie');
		if(!empty($aCat) and array_key_exists($aCat, $instance->aCats)) {
			$catIds = array($aCat);
		} else {
			$catIds = !empty($instance->aCats) ? array_keys($instance->aCats) : '000';
			shuffle($catIds);
		}

		$author = $this->getParam('author');
		if(empty($author)) {
			if(count($instance->aUsers) > 1) {
				$authors = array_keys(
					array_filter(
						$instance->aUsers,
						function($infos) {
							return !empty($infos['active']) && !empty($infos['delete']);
						}
					)
				);
				shuffle($authors);
			} else {
				$author = array_keys($instance->aUsers)[0];
			}
		}

		// -------------- On boucle sur les articles -----------

		for($i=0, $iMax=$this->getParam('articles'); $i<$iMax; $i++) { # On boucle sur les articles

			$body = array();
			for($j=0; $j<$jMax; $j++) {
				$size = mt_rand($min, $max); // Nbre de caractères / self::STEP_SIZE
				$k = $this->sizes[$size][array_rand($this->sizes[$size])];
				$body[] = $this->entries[$k];
			}

			$tagsCount = mt_rand(1, 5);
			$tags = array();
			for($k=0, $kMax=mt_rand(1, 5); $k<$kMax; $k++) {
				$tags[] = $this->tags[self::__array_rand($this->tags)];
			}
			sort($tags);

			$size = mt_rand(2, 3);
			$k = $this->sizes[$size][array_rand($this->sizes[$size])];
			$title = $this->entries[$k];
			$title = preg_replace('@^\W*([a-z].*[a-z])\W*$@i', "$1", str_replace(array('.', '»', '«'), ' ', $title)); // Pas de point pour l'Url

			// Pour éviter des urls en double
			if(array_key_exists($k, $titlesList)) {
				$titlesList[$k]++;
				$title .= ' (' . $titlesList[$k] . ')';
			} else {
				$titlesList[$k] = 1;
			}

			$thumbnail = empty($medias) ? '' : $medias[array_rand($medias)];

			if(count($catIds) > 1) {
				$catCount = mt_rand(0, count($catIds) - 1);
				if($catCount == 0) {
					$cats = array('000');
				} else {
					$cats = array();
					for($k=0; $k<$catCount; $k++) {
						$cats[] = $catIds[self::__array_rand($catIds)];
					}
				}
			}

			$id = str_pad($artIdNum, 4, '0', STR_PAD_LEFT);
			$theDate = mt_rand($periode_start, $periode_end);
			$content = array(
				'artId'		=> $id,
				'title'		=> ucfirst($title),
				'url'		=> '',
				'allow_com'	=> 1,
				'template'	=> $this->getParam('template'),
				'catId'		=> (count($catIds) == 1) ? $catIds : array_unique($cats),
				'author'	=> !empty($authors) ? $authors[self::__array_rand($authors)] : $author,
				'chapo'		=> self::CONTENT_START . array_pop($body) . self::CONTENT_END,
				'content'	=> self::CONTENT_START . implode(self::CONTENT_SEP, $body) . self::CONTENT_END,
				'tags'		=> implode(',', array_unique($tags)),
				'thumbnail'	=> $thumbnail,
				'thumbnail_alt'		=> ucfirst(preg_replace('@\.w+$@', '', basename($thumbnail))), // Suppression de l'extension du fichier
				'date_update_old'	=> date('YmdHi', $theDate),
			);

			list($year, $month, $day, $time) = explode('|', date('Y|m|d|H:i', $theDate));
			foreach(array('creation', 'update', 'publication') as $event) {
				$content['date_' . $event . '_year'] = $year;
				$content['date_' . $event . '_month'] = $month;
				$content['date_' . $event . '_day'] = $day;
				$content['date_' . $event . '_time'] = $time;
			}

			$instance->editArticle($content, $id);

			$artIdNum++;
		}
	}

	/* ---------- Hooks ---------- */
	public function AdminTopEndHead() {
		echo '<?php' . PHP_EOL;
?>
if(!array_key_exists('<?= __CLASS__ ?>', $plxAdmin->plxPlugins->aPlugins)) {
	$plxAdmin->plxPlugins->aPlugins['<?= __CLASS__ ?>']->printStylesheet();
}
<?php
		echo PHP_EOL . '?>';
	}
}

?>

==> kzFauxTexte-1_0_1.zip: kzFauxTexte/kzFauxTexte.php <==
<?php
if(!defined('PLX_ROOT')) { exit; }

/**
 * Plugin kzFauxTexte
 *
 * @author	Jean-Pierre Pourrez @bazooka07
 * @version 1.0.1 : Fix for PHP-8.3.7
 **/
class kzFauxTexte extends plxPlugin {

	const HOOKS = array(
		'AdminTopEndHead',
	);

	const DEBUG = false;

	const MIN_ARTS = 2;
	const MAX_ARTS = 9990;
	const MIN_PARAS = 2;
	const MAX_PARAS = 9;
	const MIN_SIZE = 40;
	const MAX_SIZE = 500;
	const STEP_SIZE = 20;
	const TAGS_COUNT = 30;

	const CONTENT_START = '<p>' . PHP_EOL;
	const CONTENT_END = PHP_EOL . '<p>';
	const CONTENT_SEP = PHP_EOL . '</p><p>' . PHP_EOL;

	// Pour la recherche de tags: mots à exclure
	const PATTERN = '@(?:ai(?:en)?t|ent|aujourd|encore|quelques?|(?:ce)?pendant|de(?:puis|vant)|contre|jamais|contre|maintenant|toutes|monsieur|madame|beaucoup|lorsque?|ailleurs|chaque)$@';
	public  $default_values = array(
		'ebook'			=> '',
		'paragraphs'	=> 6,
		'minsize'		=> 60,
		'maxsize'		=> 400,
		'articles'		=> 120,
		'author'		=> '',
		'categorie'		=> '',
		'medias'		=> '',
		'thumb'			=> 0,
		'begin'			=> '',
		'template'		=> 'article.php',
		'replace_all'	=> '0', // replace each old article with a new one.
	);
	private $_tags = null;
	private $_sizes = null;
	private $_entries = null;

	public function __construct($lang) {
		parent::__construct($lang);

		if(!defined('PLX_ADMIN')) { return; }

		$this->setAdminProfil(PROFIL_ADMIN);
		$this->setAdminMenu($this->getLang('FAUX_TEXTE'), false, 'Plugin ' . __CLASS__);
		foreach(self::HOOKS as $hook) {
			$this->addHook($hook, $hook);
		}
		$this->default_values['begin'] = date('Y-m-d', time() - 47304000); // 365jours x 1.5
	}

	public function getEbooks() {
		$result = array();
		foreach(array_map(
			function($item) { return basename($item, '.epub'); },
			glob(PLX_PLUGINS . __CLASS__ . '/*.epub')) as $k
		) {
			$result[$k] = $k;
		}
		return  $result;
	}

	public function getAuthors() {
		$instance = plxAdmin::getInstance();
		$result = array('' => $this->getLang('ALL'));
		foreach($instance->aUsers as $id=>$infos) {
			$result[$id] = $infos['name'];
		}
		return $result;
	}

	public function getCategories() {
		$instance = plxAdmin::getInstance();
		$result = array(
			''		=> $this->getLang('ALL'),
			'000'	=> L_UNCLASSIFIED,
		);
		foreach($instance->aCats as $id=>$infos) {
			$result[$id] = $infos['name'];
		}
		return $result;
	}

	public function getMedias() {
		$instance = plxAdmin::getInstance();
		if(empty($instance->aConf['medias'])) {
			return array('NONE');
		}

		$root = rtrim(PLX_ROOT . $instance->aConf['medias'], '/');
		$start = strlen(PLX_ROOT);
		$motif = '/*';
		$folders =  array(
			'' => $this->getLang('NONE'),
			rtrim($instance->aConf['medias'], '/') => $this->getLang('ROOT'),
		);
		for($i=1; $i<5; $i++) {
			$buffer = array_map(
				function($item) use($start) { return substr($item, $start); },
				glob($root . str_repeat($motif, $i), GLOB_ONLYDIR));
			if(empty($buffer)) { break; }
			foreach($buffer as $k=>$v) {
				// $last = ($k < count($buffer) - 1) ? '├─ ' : '└─ ';
				// $folders[$v] = str_repeat('│  ', $i - 1) . $last . basename($v); // Not a space, but u+2007 (figure space)
				$folders[$v] = str_repeat('   ', $i) . basename($v); // Not a space, but u+2007 (figure space)
			}
		}
		ksort($folders);
		return $folders;
	}

	public function getTemplates() {
		$result = array();
		$instance = plxAdmin::getInstance();
		foreach(glob(PLX_ROOT . $instance->aConf['racine_themes'] . $instance->aConf['style'] . '/article*.php') as $filename) {
			$result[basename($filename)] = basename($filename, '.php');
		}
		return $result;
	}


	public function printStylesheet() {
?>
		<link rel="stylesheet" href="<?= PLX_PLUGINS . __CLASS__ ?>/css/admin.css" />
<?php
	}

	// Pseudo tirage gaussien
	private function __array_rand(array &$t) {
		$average = intval(count($t) / 2);
		return mt_rand(mt_rand(0, $average), mt_rand($average, count($t)-1));
	}

	private function parseEbook(string $filename) {
		$zip = new ZipArchive;
		if($zip->open($filename) === true) {
			$content = $zip->getFromName('META-INF/container.xml');
			$doc = simplexml_load_string($content);
			$rootfile = $doc->rootfiles[0]->rootfile['full-path'];

			$content = $zip->getFromName($rootfile);
			$doc = simplexml_load_string($content);

			$this->_entries = array();
			$this->_sizes = array();
			$words = array();
			$doc->registerXPathNamespace('a', 'http://www.idpf.org/2007/opf');
			foreach($doc->xpath('//a:manifest/a:item[@media-type="application/xhtml+xml"]') as $t) {
				$href = dirname($rootfile) . '/' . $t['href'];
				$content = $zip->getFromName($href);
				$dom = new DomDocument;
				$dom->loadHTML($content);
				# On recherche les balises <p>
				foreach($dom->getElementsByTagName('p') as $paragraph) {
					$value = trim(preg_replace('@[\r\n]+@', ' ', $paragraph->nodeValue));
					$size = strlen($value);
					if($size >= 40 and $size <= self::MAX_SIZE) { // Entre 72 et 400 octets par entrée
						$n = count($this->_entries);
						$this->_entries[] = $value;
						$k = intval(round($size / self::STEP_SIZE));
						if(empty($this->_sizes[$k])) {
							$this->_sizes[$k] = array($n);
						} else {
							$this->_sizes[$k][] = $n;
						}
						if(preg_match_all('@(\w{6,})@mu', strtolower($value), $matches)) {
							foreach($matches[1] as $w) {
								// On exclut certains mots
								if(preg_match(self::PATTERN, $w) == 0) {
									if(array_key_exists($w, $words)) {
										$words[$w]++;
									} else {
										$words[$w] = 1;
									}
								}
							}

						}
					}
				}
			}
			$zip->close();
			foreach(array_keys($this->_sizes) as $k) {
				shuffle($this->_sizes[$k]);
			}
			ksort($this->_sizes);
			arsort($words);
			$this->_tags = array_slice(array_keys($words), 0, self::TAGS_COUNT);
			shuffle($this->_tags);

			if(self::DEBUG) {
				$output = array();
				foreach($words as $k=>$v) {
					$output[] = $k . ' : ' . $v;
				}
				file_put_contents(preg_replace('@\.xml$@', '.srt', $this->plug['parameters.xml']), implode(PHP_EOL, $output));
			}
		}
	}

	public function createArticles() {
		// Tester si le livre existe toujours
		$this->parseEbook(PLX_PLUGINS . __CLASS__ . '/' . $this->getParam('ebook') . '.epub');
		if(empty($this->_entries)) { return; }

		$instance = plxAdmin::getInstance();

		# La liste des articles n'est pas actualisée en temps réel ( plxAdmin::nextIdArticle() )
		$aKeys = array_keys($instance->plxGlob_arts->aFiles);
		$artIdNum = 1;

		if(!empty($this->getParam('replace_all'))) {
			// On supprime tous les articles existants
			foreach($aKeys as $idArt) {
				$instance->delArticle($idArt);
			}
		} elseif(!empty($aKeys)) {
			rsort($aKeys);
			$artIdNum = intval(ltrim($aKeys[0], '0')) + 1;
		}

		$jMax = $this->getParam('paragraphs') + 1; // Un paragraphe supplémentaire pour le chapo
		$min = $this->getParam('minsize') / self::STEP_SIZE;
		$max = $this->getParam('maxsize') / self::STEP_SIZE;
		if($max < $min) { $max = $min; }

		$folder = rtrim($this->getParam('medias'), '/');
		if(!empty($folder)) {
			$start = strlen(PLX_ROOT);
			$medias = array_map(
				function($item) use($start) {
					return substr($item, $start); // On vire PLX_ROOT
				},
				array_filter(
					glob(PLX_ROOT . $folder . '/*'),
					function($filename) { return (preg_match('@(\.tb)?\.(?:jpe?g|png|gif|svg)$@', basename($filename), $matches) and empty($matches[1])); }
				)
			);
			if(empty($this->getParam('thumb'))) {
				$medias[] = ''; // article sans vignette
			}
		} else {
			$medias = false;
		}

		list($year, $month, $day) = explode('-', $this->getParam('begin'));
		$periode_start = mktime(0, 0, 0, ltrim($month, '0'), ltrim($day, '0'), $year);
		$periode_end = time();

		$titlesList = array();

		$aCat = $this->getParam('categorie');
		if(!empty($aCat) and array_key_exists($aCat, $instance->aCats)) {
			$catIds = array($aCat);
		} else {
			$catIds = !empty($instance->aCats) ? array_keys($instance->aCats) : '000';
			shuffle($catIds);
		}

		$author = $this->getParam('author');
		if(empty($author)) {
			if(count($instance->aUsers) > 1) {
				$authors = array_keys(
					array_filter(
						$instance->aUsers,
						function($infos) {
							return !empty($infos['active']) && empty($infos['delete']);
						}
					)
				);
				shuffle($authors);
			} else {
				$author = array_keys($instance->aUsers)[0];
			}
		}

		// -------------- On boucle sur les articles -----------

		for($i=0, $iMax=$this->getParam('articles'); $i<$iMax; $i++) { # On boucle sur les articles

			$body = array();
			for($j=0; $j<$jMax; $j++) {
				$size = mt_rand($min, $max); // Nbre de caractères / self::STEP_SIZE
				$k = $this->_sizes[$size][array_rand($this->_sizes[$size])];
				$body[] = $this->_entries[$k];
			}

			$tagsCount = mt_rand(1, 5);
			$tags = array();
			for($k=0, $kMax=mt_rand(1, 5); $k<$kMax; $k++) {
				$tags[] = $this->_tags[self::__array_rand($this->_tags)];
			}
			sort($tags);

			$size = mt_rand(2, 3);
			$k = $this->_sizes[$size][array_rand($this->_sizes[$size])];
			$title = $this->_entries[$k];
			$title = preg_replace('@^\W*([a-z].*[a-z])\W*$@i', "$1", str_replace(array('.', '»', '«'), ' ', $title)); // Pas de point pour l'Url

			// Pour éviter des urls en double
			if(array_key_exists($k, $titlesList)) {
				$titlesList[$k]++;
				$title .= ' (' . $titlesList[$k] . ')';
			} else {
				$titlesList[$k] = 1;
			}

			$thumbnail = empty($medias) ? '' : $medias[array_rand($medias)];

			if(count($catIds) > 1) {
				$catCount = mt_rand(0, count($catIds) - 1);
				if($catCount == 0) {
					$cats = array('000');
				} else {
					$cats = array();
					for($k=0; $k<$catCount; $k++) {
						$cats[] = $catIds[self::__array_rand($catIds)];
					}
				}
			}

			$id = str_pad($artIdNum, 4, '0', STR_PAD_LEFT);
			$theDate = mt_rand($periode_start, $periode_end);
			$content = array(
				'artId'		=> $id,
				'title'		=> ucfirst($title),
				'url'		=> '',
				'allow_com'	=> 1,
				'template'	=> $this->getParam('template'),
				'catId'		=> (count($catIds) == 1) ? $catIds : array_unique($cats),
				'author'	=> !empty($authors) ? $authors[self::__array_rand($authors)] : $author,
				'chapo'		=> self::CONTENT_START . array_pop($body) . self::CONTENT_END,
				'content'	=> self::CONTENT_START . implode(self::CONTENT_SEP, $body) . self::CONTENT_END,
				'tags'		=> implode(',', array_unique($tags)),
				'thumbnail'	=> $thumbnail,
				'thumbnail_alt'		=> ucfirst(preg_replace('@\.w+$@', '', basename($thumbnail))), // Suppression de l'extension du fichier
				'date_update_old'	=> date('YmdHi', $theDate),
			);

			list($year, $month, $day, $time) = explode('|', date('Y|m|d|H:i', $theDate));
			foreach(array('creation', 'update', 'publication') as $event) {
				$content['date_' . $event . '_year'] = $year;
				$content['date_' . $event . '_month'] = $month;
				$content['date_' . $event . '_day'] = $day;
				$content['date_' . $event . '_time'] = $time;
			}

			$instance->editArticle($content, $id);

			$artIdNum++;
		}
	}

	/* ---------- Hooks ---------- */
	public function AdminTopEndHead() {
		echo '<?php' . PHP_EOL;
?>
if(!array_key_exists('<?= __CLASS__ ?>', $plxAdmin->plxPlugins->aPlugins)) {
	$plxAdmin->plxPlugins->aPlugins['<?= __CLASS__ ?>']->printStylesheet();
}
<?php
		echo PHP_EOL . '?>';
	}
}
